# outerport/models/document_model.py
from __future__ import annotations
from typing import Optional
from pydantic import BaseModel, PrivateAttr
from datetime import datetime


class Document(BaseModel):
    """
    A Pydantic model that represents a Document in your API.
    """

    id: int
    name: str
    folder_id: Optional[int] = None
    file_path: Optional[str] = None
    file_type: str
    file_url: Optional[str] = None
    summary: str
    version: int
    created_at: datetime
    updated_at: datetime

    # Private attribute to store the client
    _client = PrivateAttr()

    def __init__(self, **data):
        """
        Pydantic's __init__ is overridden so we can attach _client after the model is constructed.
        """
        client = data.pop("_client", None)
        super().__init__(**data)
        self._client = client

    def delete(self) -> dict:
        """
        Delete this document on the server.
        """
        return self._client.documents.delete(self.id)

    def reload(self) -> None:
        """
        Refresh this Document with the latest data from the server.
        """
        fresh = self._client.documents.retrieve(self.id)
        # Update current model in-place
        for field_name, value in fresh.dict().items():
            if field_name != "_client":
                setattr(self, field_name, value)

    @classmethod
    def from_api(cls, data: dict, client):
        """
        Helper to create a Document from an API response dict plus the client reference.
        """
        # The API might return 'id' or 'document_id'. Adjust as needed.
        if "document_id" in data and "id" not in data:
            data["id"] = data.pop("document_id")
        return cls(_client=client, **data)
